slepc-3.18.0 2022-10-01
Report Typos and Errors

# EPSMonitorConverged

Print the approximate values and error estimates as they converge.

### Synopsis

    #include "slepceps.h"
    PetscErrorCode EPSMonitorConverged(EPS eps,PetscInt its,PetscInt nconv,PetscScalar *eigr,PetscScalar *eigi,PetscReal *errest,PetscInt nest,PetscViewerAndFormat *vf)

Collective on eps

### Input Parameters

| eps | - eigensolver context
| its | - iteration number
| nconv | - number of converged eigenpairs so far
| eigr | - real part of the eigenvalues
| eigi | - imaginary part of the eigenvalues
| errest | - error estimates
| nest | - number of error estimates to display
| vf | - viewer and format for monitoring

### Options Database Key

| -eps_monitor_conv | - activates EPSMonitorConverged()

### See Also

EPSMonitorSet(), EPSMonitorFirst(), EPSMonitorAll()

### Level

intermediate

### Location

src/eps/interface/epsmon.c
Index of all EPS routines
Table of Contents for all manual pages
Index of all manual pages